@@ -1,4 +1,4 @@
-"""Allow users to access circuitry symbols directly."""
+"""Gives users direct access to classes, functions, and decorator."""
 from circuitry.circuitry import\
     bit, constant, input, input_one, input_two, output,\
     bits, constants, inputs, outputs,\
